@@ -2,8 +2,8 @@
 """
 no particle precipitation
 """
-import glowpython2 as glow
-from glowpython2.plots import Plot
+import glowpython as glow
+import glowpython.plots as plot
 from datetime import datetime
 from matplotlib.pyplot import show
 
@@ -20,9 +20,10 @@ if False:
     plot.precip(iono["precip"])  # all zeros as intended
     plot.altitude(iono)
 
-plot = Plot()
 plot.density(iono)
+
 plot.temperature(iono)
+
 plot.ver(iono)
 
 show()
