@@ -83,23 +83,23 @@ subroutine ephoto
             rion(lmax,nmaj,jmax)
 
   real,parameter :: signo = 2.0e-18
-  integer :: l,n,k,i,j,m1,m2
+  integer :: l,n,k,i,j,m,m1,m2
   real :: fac,e1,e2,y,r1,r2
 
   nnn = (/5,4,6/)
-  tpot(1:nst,1) = (/13.61, 16.93, 18.63, 28.50, 40.00,  0.00/) ! ionization potential for O, eV [4S, 2Do, 2Po, 4Pe, 2Pe]
-  tpot(1:nst,2) = (/12.07, 16.10, 18.20, 20.00,  0.00,  0.00/) ! ionization potential for O2, eV [X, a+A, b, dissoc.]
-  tpot(1:nst,3) = (/15.60, 16.70, 18.80, 30.00, 34.80, 25.00/) ! ionization potential for N2, eV [X, A, B, C, F, dissoc.]
-  auge = (/500.,500.,360./) ! mean energy of Auger electrons for O, O2, N2; eV
-  augl = (/24.,24.,33./) ! wavelength threshold for Auger electrons for O, O2, N2; Angstroms
-  bso2(1:12) = 0.0 ! yield of O(1S) from dissociation of O2
-  bso2(13) = 0.01
-  bso2(14) = 0.03
-  bso2(15:21) = 0.10
-  bso2(22:29) = 0.07
-  bso2(30:34) = 0.03
-  bso2(35:39) = 0.01
-  bso2(40:lmax) = 0.0
+  tpot(1:nst,1) = (/13.61, 16.93, 18.63, 28.50, 40.00,  0.00/)
+  tpot(1:nst,2) = (/12.07, 16.10, 18.20, 20.00,  0.00,  0.00/)
+  tpot(1:nst,3) = (/15.60, 16.70, 18.80, 30.00, 34.80, 25.00/)
+  auge = (/500.,500.,360./)
+  augl = (/24.,24.,33./)
+  bso2(1:12) = 0.
+  bso2(13) = .01
+  bso2(14) = .03
+  bso2(15:21) = .10
+  bso2(22:29) = .07
+  bso2(30:34) = .03
+  bso2(35:39) = .01
+  bso2(40:lmax) = 0.
 
 ! Zero arrays:
 
@@ -110,13 +110,13 @@ subroutine ephoto
 
 ! Calculate attenuated solar flux at all altitudes and wavelengths:
 
-  do l=1,lmax ! for all wavelengths
-    do j=1,jmax ! for all altitudes
-      tau(l)=0.  ! initialize optical depth
-      do i=1,nmaj ! for all species
-        tau(l)=tau(l)+sigabs(i,l)*zcol(i,j) ! total optical depth
+  do l=1,lmax 
+    do j=1,jmax
+      tau(l)=0. 
+      do i=1,nmaj 
+        tau(l)=tau(l)+sigabs(i,l)*zcol(i,j) 
       enddo
-      if (tau(l) < 20.) then ! optical depth cutoff: 20.0, i.e. exp(-20) = 2.1e-9 ~ 0
+      if (tau(l) < 20.) then
         flux(l,j)=sflux(l)*exp(-tau(l)) 
       else
         flux(l,j) = 0.0
